Pinnacle Export Tool — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# Pinnacle Export Tool

Export DICOM objects from raw Pinnacle data.

Warning

The DICOM objects exported by this tool are not the same as the DICOM objects exported from within the Pinnacle application. Certain DICOM modalities correspond fairly well to the Pinnacle exported objects for some versions of Pinnacle. Others are not working as expected or have not been validated.

The first step when using this tool is to compare the output generated to the ‘ground truth’ generated by your version(s) of Pinnacle. You can then determine if this tool currently meets your export needs, or if some adjustments need to be made. Please create an issue on the PyMedPhys GitHub describing the circumstances where the tool is not working, providing some sample raw Pinnacle data where possible. If you’re up for a challenge, clone the PyMedPhys repository and attempt to solve the problem yourself! Don’t be afraid to ask for help when contributing your changes. The more developers we can encourage to contribute to this tool, the sooner it will become stable and reliable.

Finally, note that while this tool can be extremely useful for exporting large amounts of Pinnacle data to DICOM, we recommend that this should only be used for research purposes and not clinically.

    usage: pymedphys experimental pinnacle [-h] {export} ...

## Positional Arguments

`pinnacle`

  Possible choices: export

## Sub-commands

### export

Export a raw file to DICOM

    pymedphys experimental pinnacle export [-h] [-o OUTPUT_DIRECTORY] [-v] [--mrn] [-l] [-m MODALITY] [-p PLAN] [-t TRIAL]
                                           [-i IMAGE] [-u UID_PREFIX] [-r ROISKIP]
                                           input_path

#### Positional Arguments

`input_path`

  Root Patient directory of raw Pinnacle data (directory containing the ‘Patient’ file). Alternatively a TAR archive can be supplied.

#### Named Arguments

`-o, --output-directory`

  Directory in which to generate DICOM objects.

`-v, --verbose`

  Flag to output debug information.

  Default: False

`--mrn`

  Append the Patient ID/MRN to the end of the name of the export folder

  Default: False

`-l, --list`

  List all plans and trials available.

  Default: False

`-m, --modality`

  Modalities to export (CT exports the plans primary planning CT).

  Default: []

`-p, --plan`

  The name of the plan to export (first plan will be exported by default).

`-t, --trial`

  The name of the trial to export (first trial will be exported by default).

`-i, --image`

  The UID of an image series you would like to export (or ‘all’ to export all images).

`-u, --uid-prefix`

  Prefix to use for generated UIDs.

`-r, --roiskip`

  Regular expression defining which ROIs to skip. Note that you will probably need to enclose your regular expression in single-quotes. For example ‘Skin|.*_obj|RadCalc’ .